// Copyright (C) 2023  Nexedi SA and Contributors.
//                     Kirill Smelkov <kirr@nexedi.com>
//
// This program is free software: you can Use, Study, Modify and Redistribute
// it under the terms of the GNU General Public License version 3, or (at your
// option) any later version, as published by the Free Software Foundation.
//
// You can also Link and Combine this program with other software covered by
// the terms of any of the Free Software licenses or any of the Open Source
// Initiative approved licenses and Convey the resulting work. Corresponding
// source of such a combination shall include the source code for all other
// software used.
//
// This program is distributed WITHOUT ANY WARRANTY; without even the implied
// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// See COPYING file for full licensing terms.
// See https://www.nexedi.com/licensing for rationale and options.

package proto

import (
	"testing"
)


func TestNotPrimaryMasterError(t *testing.T) {
	var testv = []struct {
		msg    *NotPrimaryMaster
		estrok string
	}{
		{&NotPrimaryMaster{},
			"not primary master; primary: ? ; known masters: []",
		},

		{&NotPrimaryMaster{1, nil},
			"not primary master; primary: ? ; known masters: []",
		},

		{&NotPrimaryMaster{1, []struct{Address}{{Address{"α",111}}, {Address{"β",222}}, {Address{"γ",333}}}},
			"not primary master; primary: β:222 ; known masters: [α:111 β:222 γ:333]",
		},
	}

	for _, tt := range testv {
		estr := tt.msg.Error()
		if estr != tt.estrok {
			t.Errorf("%v: invalid error:\nhave: %q\nwant: %q", tt.msg, estr, tt.estrok)
		}
	}
}
